# AutoEFT BSM Model Files

This folder contains AutoEFT *model files* for various low-energy scenarios related to beyond the Standard Model (BSM) physics as proposed in:

[**Effective Operator Bases for Beyond Standard Model Scenarios: An EFT compendium for discoveries**](https://inspirehep.net/literature/1813374)  
U. Banerjee, J. Chakrabortty, S. Prakash, S.U. Rahaman, M. Spannowsky  
[_JHEP_ **01** (2021) 028](https://doi.org/10.1007/JHEP01(2021)028),
[arXiv:2008.11512 [hep-ph]](https://arxiv.org/abs/2008.11512)

## Standard Model extended by uncolored particles
| model                                | file                 | no. |
|--------------------------------------|----------------------|----:|
| **SM + Singly Charged Scalar**       | [scs+sm](scs+sm.yml) | 1   |
| **SM + Doubly Charged Scalar**       | [dcs+sm](dcs+sm.yml) | 2   |
| **SM + Complex Triplet Scalar**      | [cts+sm](cts+sm.yml) | 3   |
| **SM + Left-Handed Triplet Fermion** | [ltf+sm](ltf+sm.yml) | 4   |
| **SM + Vector-like Leptons**         | [vll+sm](vll+sm.yml) | 5   |

## Standard Model extended by colored particles
| model                | file                   | no. |
|----------------------|------------------------|----:|
| **SM + Lepto-Quark** | [lqc1+sm](lqc1+sm.yml) | 1   |
| **SM + Lepto-Quark** | [lqp1+sm](lqp1+sm.yml) | 2   |

## Standard Model extended by abelian gauge symmetries
| model                                       | file                     |
|---------------------------------------------|--------------------------|
| SM extended by two abelian gauge symmetries | [u1-u1-sm](u1-u1-sm.yml) |

## BSMEFT: a few more popular scenarios
| model                            | file                   |
|----------------------------------|------------------------|
| **SM + SU(2) Quadruplet Scalar** | [cqs+sm](cqs+sm.yml)   |
| **SM + Lepto-Quarks**            | [lqc2+sm](lqc2+sm.yml) |
| **SM + Lepto-Quarks**            | [lqp2+sm](lqp2+sm.yml) |
